import * as ec2 from '@aws-cdk/aws-ec2';
import * as kms from '@aws-cdk/aws-kms';
import { Construct, Resource } from '@aws-cdk/core';
/**
 * EFS Lifecycle Policy, if a file is not accessed for given days, it will move to EFS Infrequent Access.
 *
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html#cfn-elasticfilesystem-filesystem-lifecyclepolicies
 */
export declare enum EfsLifecyclePolicyProperty {
    /**
     * After 7 days of not being accessed.
     */
    AFTER_7_DAYS = 0,
    /**
     * After 14 days of not being accessed.
     */
    AFTER_14_DAYS = 1,
    /**
     * After 30 days of not being accessed.
     */
    AFTER_30_DAYS = 2,
    /**
     * After 60 days of not being accessed.
     */
    AFTER_60_DAYS = 3,
    /**
     * After 90 days of not being accessed.
     */
    AFTER_90_DAYS = 4
}
/**
 * EFS Performance mode.
 *
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html#cfn-efs-filesystem-performancemode
 */
export declare enum EfsPerformanceMode {
    /**
     * This is the general purpose performance mode for most file systems.
     */
    GENERAL_PURPOSE = "generalPurpose",
    /**
     * This performance mode can scale to higher levels of aggregate throughput and operations per second with a
     * tradeoff of slightly higher latencies.
     */
    MAX_IO = "maxIO"
}
/**
 * EFS Throughput mode.
 *
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html#cfn-elasticfilesystem-filesystem-throughputmode
 */
export declare enum EfsThroughputMode {
    /**
     *  This mode on Amazon EFS scales as the size of the file system in the standard storage class grows.
     */
    BURSTING = "bursting",
    /**
     * This mode can instantly provision the throughput of the file system (in MiB/s) independent of the amount of data stored.
     */
    PROVISIONED = "provisioned"
}
/**
 * Interface to implement AWS File Systems.
 */
export interface IEfsFileSystem extends ec2.IConnectable {
    /**
     * The ID of the file system, assigned by Amazon EFS.
     *
     * @attribute
     */
    readonly fileSystemId: string;
}
/**
 * Properties of EFS FileSystem.
 */
export interface EfsFileSystemProps {
    /**
     * VPC to launch the file system in.
     */
    readonly vpc: ec2.IVpc;
    /**
     * Security Group to assign to this file system.
     *
     * @default - creates new security group which allow all out bound traffic
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * Where to place the mount target within the VPC.
     *
     * @default - Private subnets
     */
    readonly vpcSubnets?: ec2.SubnetSelection;
    /**
     * Defines if the data at rest in the file system is encrypted or not.
     *
     * @default - false
     */
    readonly encrypted?: boolean;
    /**
     * The KMS key used for encryption. This is required to encrypt the data at rest if @encrypted is set to true.
     *
     * @default - if @encrypted is true, the default key for EFS (/aws/elasticfilesystem) is used
     */
    readonly kmsKey?: kms.IKey;
    /**
     * A policy used by EFS lifecycle management to transition files to the Infrequent Access (IA) storage class.
     *
     * @default - none
     */
    readonly lifecyclePolicy?: EfsLifecyclePolicyProperty;
    /**
     * Enum to mention the performance mode of the file system.
     *
     * @default - GENERAL_PURPOSE
     */
    readonly performanceMode?: EfsPerformanceMode;
    /**
     * Enum to mention the throughput mode of the file system.
     *
     * @default - BURSTING
     */
    readonly throughputMode?: EfsThroughputMode;
    /**
     * Provisioned throughput for the file system. This is a required property if the throughput mode is set to PROVISIONED.
     * Valid values are 1-1024.
     *
     * @default - None, errors out
     */
    readonly provisionedThroughputInMibps?: number;
}
/**
 *  A new or imported EFS File System.
 */
declare abstract class EfsFileSystemBase extends Resource implements IEfsFileSystem {
    /**
     * The security groups/rules used to allow network connections to the file system.
     */
    abstract readonly connections: ec2.Connections;
    /**
     * @attribute
     */
    abstract readonly fileSystemId: string;
}
/**
 * Properties that describe an existing EFS file system.
 */
export interface EfsFileSystemAttributes {
    /**
     * The security group of the file system
     */
    readonly securityGroup: ec2.ISecurityGroup;
    /**
     * The File System's ID.
     */
    readonly fileSystemID: string;
}
/**
 * The Elastic File System implementation of IFileSystem.
 * It creates a new, empty file system in Amazon Elastic File System (Amazon EFS).
 * It also creates mount target (AWS::EFS::MountTarget) implicitly to mount the
 * EFS file system on an Amazon Elastic Compute Cloud (Amazon EC2) instance or another resource.
 *
 * @see https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html
 *
 * @resource AWS::EFS::FileSystem
 */
export declare class EfsFileSystem extends EfsFileSystemBase {
    /**
     * Import an existing File System from the given properties.
     */
    static fromEfsFileSystemAttributes(scope: Construct, id: string, attrs: EfsFileSystemAttributes): IEfsFileSystem;
    /**
     * The default port File System listens on.
     */
    private static readonly DEFAULT_PORT;
    /**
     * The security groups/rules used to allow network connections to the file system.
     */
    readonly connections: ec2.Connections;
    /**
     * @attribute
     */
    readonly fileSystemId: string;
    private readonly efsFileSystem;
    /**
     * Constructor for creating a new EFS FileSystem.
     */
    constructor(scope: Construct, id: string, props: EfsFileSystemProps);
}
export {};
